<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
 * User preferences form
 *
 * @package PhpMyAdmin
 */
declare(strict_types=1);

namespace PhpMyAdmin\Config\Forms\Page;

/**
 * Class ExportForm
 * @package PhpMyAdmin\Config\Forms\Page
 */
class ExportForm extends \PhpMyAdmin\Config\Forms\User\ExportForm
{
}
